@@ -12,8 +12,9 @@
   packageStartupMessage("------------------------------------------------------------")
   packageStartupMessage("** tvR")
   packageStartupMessage("**  - Total Variation Regularization")
+  packageStartupMessage("** ")
   packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You (kyoustat@gmail.com)")
+  packageStartupMessage("** Maintainer : Kisung You (kisungyou@outlook.com)")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
   packageStartupMessage("------------------------------------------------------------")
